# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.supportedFilesystems = [ "ntfs" ];
  boot.kernelPackages = pkgs.linuxPackages_latest;
  virtualisation.virtualbox.host.enable = true;
  hardware.opengl.driSupport32Bit = true; 
   networking.hostName = "nixos"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

  # The global useDHCP flag is deprecated, therefore explicitly set to false here.
  # Per-interface useDHCP will be mandatory in the future, so this generated config
  # replicates the default behaviour.
  #networking.useDHCP = false;
  #networking.interfaces.enp2s0.useDHCP = true;
  #My edits
  networking.networkmanager.enable = true;
  #networking.networkmanager.unmanaged = [
  # "*" "except:type:wwan" "except:type:gsm"
  # ];

  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Select internationalisation properties.
   i18n.defaultLocale = "en_US.UTF-8";
   console = {
     font = "Lat2-Terminus16";
     keyMap = "us";
   };

  # Set your time zone.
   time.timeZone = "America/New_York";

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  # environment.systemPackages = with pkgs; [
  #   wget vim
  # ];
  nixpkgs.config.allowUnfree = true;
  services.flatpak.enable = true;
  services.dbus.enable = true;
  services.dbus.packages = with pkgs; [ snapper ];
  services.cron.enable = true;
  environment.systemPackages = 
   [
     pkgs.thunderbird
     pkgs.tmux
     pkgs.firefox
     pkgs.mpv
     pkgs.vlc
     pkgs.retroarchBare
     pkgs.emacs
     pkgs.weechat
     pkgs.mame
     pkgs.dosbox
     pkgs.obs-studio
     pkgs.ntfs3g
     pkgs.nfs-utils
     pkgs.htop
     pkgs.cmus
     pkgs.kate
     pkgs.arena
     pkgs.chocolateDoom
     pkgs.gzdoom
     pkgs.quakespasm
     pkgs.mednaffe
     pkgs.hexchat
     pkgs.yquake2
     pkgs.steam
     pkgs.ranger
     pkgs.slade
     pkgs.eduke32
     pkgs.dxx-rebirth
     pkgs.qemu
     pkgs.exfat
     pkgs.crawl
     pkgs.openmw
     pkgs.keepassxc
     pkgs.minetest
     pkgs.higan
     pkgs.nushell
     pkgs.libreoffice
     pkgs.calibre
     pkgs.zsh
    # pkgs.unstable.virtualbox
     pkgs.p7zip
     pkgs.unrar
     pkgs.kdeApplications.okular
     pkgs.gwenview
     pkgs.k3b
     pkgs.pandoc
     pkgs.tectonic
     pkgs.nextcloud-client
     pkgs.ark
     pkgs.lynx
     pkgs.snapper
     pkgs.python38Packages.snapperGUI
     pkgs.proot
     pkgs.go
     pkgs.btrbk
     pkgs.deadbeef
     pkgs.gvfs
     pkgs.smbnetfs
     pkgs.ssb-patchwork
     pkgs.toxic
     pkgs.qbittorrent
    # pkgs.linuxPackages.virtualbox
    # pkgs.retroshare
     pkgs.ipfs
     pkgs.plan9port
   ];
  services.xserver.windowManager.icewm.enable = true; 
  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  #   pinentryFlavor = "gnome3";
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
   networking.firewall.enable = false;

  # Enable CUPS to print documents.
   services.printing.enable = true;

  # Enable sound.
   sound.enable = true;
   hardware.pulseaudio.enable = true;

  # Enable the X11 windowing system.
   services.xserver.enable = true;
   services.xserver.layout = "us";
  # services.xserver.xkbOptions = "eurosign:e";

  # Enable touchpad support.
   services.xserver.libinput.enable = true;

  # Enable the KDE Desktop Environment.
   services.xserver.displayManager.sddm.enable = true;
   services.xserver.desktopManager.plasma5.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
   users.users.YourUserName = {
    isNormalUser = true;
     extraGroups = [ "wheel" "networkmanager" "vboxusers"  ]; # Enable ‘sudo’ for the user.
   };
  
  fileSystems."/home/YourUserName/nfs" = {
    device = "10.0.0.101:/home/pi/nfs-share";
    fsType = "nfs";
  };
 # boot.kernelModules = [ "vboxdrv" "vboxnetadp" "vboxnetflt" ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "20.03"; # Did you read the comment?

}

